@@ -8,7 +8,7 @@ require Gnome;
 require Exporter;
 require DynaLoader;
 
-$VERSION = '0.7008';
+$VERSION = '0.7009';
 
 @ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
@@ -21,7 +21,7 @@ $VERSION = '0.7008';
 @EXPORT_OK = qw(
 );
 
-sub dl_load_flags {0x01}
+sub dl_load_flags {Gtk::dl_load_flags()}
 
 bootstrap Gnome::Print $VERSION;
 
