@@ -4,7 +4,7 @@ require Gtk;
 require Exporter;
 require DynaLoader;
 
-$VERSION = '0.7008';
+$VERSION = '0.7009';
 
 @ISA = (@ISA, qw(Exporter DynaLoader));
 # Items to export into callers namespace by default. Note: do not export
@@ -19,7 +19,7 @@ $VERSION = '0.7008';
 
 package Gtk::XmHTML;
 
-sub dl_load_flags {0x01}
+sub dl_load_flags {Gtk::dl_load_flags()}
 
 bootstrap Gtk::XmHTML;
 
